Matrix2

Struct Matrix2 

pub struct Matrix2 {
    pub m00: f64,
    pub m01: f64,
    pub m10: f64,
    pub m11: f64,
}
A 2x2 matrix stored in row-major order.

Examples

use use_matrix::Matrix2;

let matrix = Matrix2::new(
    1.0, 2.0,
    3.0, 4.0,
);

assert_eq!(matrix.trace(), 5.0);
assert_eq!(matrix.determinant(), -2.0);

Fields

m00: f64m01: f64m10: f64m11: f64

Implementations

Source

impl Matrix2

pub const ZERO: Self

The zero matrix.

pub const IDENTITY: Self

The identity matrix.

Examples
use use_matrix::Matrix2;

let matrix = Matrix2::new(
    4.0, 7.0,
    2.0, 6.0,
);

assert_eq!(Matrix2::IDENTITY * matrix, matrix);
assert_eq!(matrix * Matrix2::IDENTITY, matrix);
pub const fn new(m00: f64, m01: f64, m10: f64, m11: f64) -> Self

Creates a matrix from row-major entries.

pub const fn from_rows(rows: [[f64; 2]; 2]) -> Self

Creates a matrix from row arrays.

pub const fn from_cols(cols: [[f64; 2]; 2]) -> Self

Creates a matrix from column arrays.

pub const fn transpose(self) -> Self

Returns the transpose.

pub const fn determinant(self) -> f64

Returns the determinant.

pub const fn trace(self) -> f64

Returns the trace.

pub fn inverse(self) -> Option<Self>

Returns the inverse when the determinant is finite and non-zero.

Returns None for singular matrices or matrices with non-finite determinants.

Examples
use use_matrix::Matrix2;

let matrix = Matrix2::new(
    4.0, 7.0,
    2.0, 6.0,
);

let inverse = matrix.inverse().expect("matrix should invert");

assert!((inverse.m00 - 0.6).abs() < 1.0e-12);
assert!((inverse.m11 - 0.4).abs() < 1.0e-12);