Matrix3

Struct Matrix3 

pub struct Matrix3 {
    pub m00: f64,
    pub m01: f64,
    pub m02: f64,
    pub m10: f64,
    pub m11: f64,
    pub m12: f64,
    pub m20: f64,
    pub m21: f64,
    pub m22: f64,
}
A 3x3 matrix stored in row-major order.

Examples

use use_matrix::Matrix3;

let matrix = Matrix3::new(
    1.0, 2.0, 3.0,
    0.0, 1.0, 4.0,
    5.0, 6.0, 0.0,
);

assert_eq!(matrix.determinant(), 1.0);

Fields

m00: f64m01: f64m02: f64m10: f64m11: f64m12: f64m20: f64m21: f64m22: f64

Implementations

Source

impl Matrix3

pub const ZERO: Self

The zero matrix.

pub const IDENTITY: Self

The identity matrix.

Examples
use use_matrix::Matrix3;

let matrix = Matrix3::new(
    2.0, 1.0, 0.0,
    0.0, 3.0, 4.0,
    0.0, 0.0, 5.0,
);

assert_eq!(Matrix3::IDENTITY * matrix, matrix);
pub const fn new( m00: f64, m01: f64, m02: f64, m10: f64, m11: f64, m12: f64, m20: f64, m21: f64, m22: f64, ) -> Self

Creates a matrix from row-major entries.

pub const fn from_rows(rows: [[f64; 3]; 3]) -> Self

Creates a matrix from row arrays.

pub const fn from_cols(cols: [[f64; 3]; 3]) -> Self

Creates a matrix from column arrays.

pub const fn transpose(self) -> Self

Returns the transpose.

pub const fn determinant(self) -> f64

Returns the determinant.

pub const fn trace(self) -> f64

Returns the trace.

pub fn inverse(self) -> Option<Self>

Returns the inverse when the determinant is finite and non-zero.

Returns None for singular matrices or matrices with non-finite determinants.

Examples
use use_matrix::Matrix3;

let matrix = Matrix3::new(
    1.0, 2.0, 3.0,
    0.0, 1.0, 4.0,
    5.0, 6.0, 0.0,
);

let inverse = matrix.inverse().expect("matrix should invert");

assert_eq!(matrix * inverse, Matrix3::IDENTITY);